==> hinemos_src-3.2.1.tar.gz: HinemosManager/src_snmptrap/com/clustercontrol/snmptrap/factory/DeleteOidMaster.java <==
/*
 
Copyright (C) 2008 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.snmptrap.factory;

import javax.ejb.CreateException;
import javax.ejb.EJBException;
import javax.ejb.FinderException;
import javax.ejb.RemoveException;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.transaction.HeuristicMixedException;
import javax.transaction.HeuristicRollbackException;
import javax.transaction.InvalidTransactionException;
import javax.transaction.NotSupportedException;
import javax.transaction.RollbackException;
import javax.transaction.SystemException;
import javax.transaction.Transaction;
import javax.transaction.TransactionManager;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.MonitorNotFoundException;
import com.clustercontrol.accesscontrol.factory.AccessLock;
import com.clustercontrol.snmptrap.bean.SnmpTrapMasterInfo;
import com.clustercontrol.snmptrap.ejb.entity.SnmpTrapMasterLocal;
import com.clustercontrol.snmptrap.ejb.entity.SnmpTrapMasterPK;
import com.clustercontrol.snmptrap.ejb.entity.SnmpTrapMasterUtil;
import com.clustercontrol.util.apllog.AplLogger;

/**
 * OIDマスター情報を削除するクラス<BR>
 *
 * @version 2.4.0
 * @since 2.4.0
 * @author Yosuke
 */
public class DeleteOidMaster {
	
	protected static Log m_log = LogFactory.getLog( DeleteOidMaster.class );
	
	
	protected SnmpTrapMasterPK m_OidPk;
	
    /**
     * OID情報を削除します。
     * 
     * @param OIDData　削除するOIDマスター
     * @param user　　　削除実行ユーザ
     * @return
     * @throws CreateException
     * @throws NotSupportedException
     * @throws RollbackException
     * @throws HeuristicMixedException
     * @throws HeuristicRollbackException
     * @throws SystemException
     * @throws InvalidTransactionException
     * @throws NamingException
     * @throws MonitorNotFoundException 
     */
	public boolean delete(SnmpTrapMasterInfo oidData) throws CreateException, NotSupportedException, RollbackException, HeuristicMixedException, HeuristicRollbackException, SystemException, InvalidTransactionException, NamingException, MonitorNotFoundException {
		
    	//アクセスロック
    	AccessLock.lock(AccessLock.MONITOR_SNMPTRAP);

    	this.m_OidPk = new SnmpTrapMasterPK(oidData.getMib(),
				   oidData.getTrapOid(),
				   oidData.getGenericId(),
				   oidData.getSpecificId());
		
		TransactionManager tm = null;
//		Transaction tx = null;
//		Transactionの利用を取りやめたため、関連箇所ふくめコメントアウトした : uchiyama		
		Transaction oldTx = null;
		boolean result = false;
		
		try 
		{
			// TransactionManagerを取得
			InitialContext context = new InitialContext();
			tm = (TransactionManager)context.lookup("java:/TransactionManager");
			
			// 実行中のスレッドがトランザクションに関連付けられている場合は、トランザクションを退避 
			if(tm.getTransaction() != null){
				oldTx = tm.suspend();
			}
			
			try{
				// トランザクション開始
				if(tm.getTransaction() == null){
					tm.begin();	
//					tx = tm.getTransaction();
				}
				
				// 監視情報を登録
				result = deleteOIDMaster();
				if(result){
					// コミット
//					tx.commit();
					tm.commit();
				}
			
			} catch(NotSupportedException e){
				outputLog(e, "delete()");
				throw e;
			} catch (RollbackException e) {
				outputLog(e, "delete()");
				throw e;
			} catch (HeuristicMixedException e) {
				outputLog(e, "delete()");
				throw e;
			} catch(HeuristicRollbackException e){
				outputLog(e, "delete()");
				throw e;
			} catch(SystemException e){
				outputLog(e, "delete()");
				throw e;
			}
			finally{
				// トランザクション関連の例外が発生した場合は、ロールバック
//				if(tx != null){
//					if(!result){
//						tx.rollback();
//					}
//					tx = null;
//				}
				if(tm.getTransaction() != null){
					if(!result){
						tm.rollback();
					}
				}
			}
		}
		finally{
			
			// 一時停止していたトランザクションを再開
			if(oldTx != null){
				try{
					tm.resume(oldTx);
				
				} catch(InvalidTransactionException e){
					outputLog(e, "delete()");
					throw e;
				} catch(IllegalStateException e){
					outputLog(e, "delete()");
					throw e;
				} catch(SystemException e){
					outputLog(e, "delete()");
					throw e;
				}
			}
		}
		return result;
	}

/**
 * OIDマスターの削除を行う。
 * @param user　削除実行ユーザ
 * @return
 * @throws NamingException
 * @throws MonitorNotFoundException 
 */
	public boolean deleteOIDMaster() throws NamingException, MonitorNotFoundException {
		boolean result = false;
		
		try 
		{
			
			// 監視情報を検索
			
			SnmpTrapMasterLocal OIDMaster =  SnmpTrapMasterUtil.getLocalHome()
			                                    .findByPrimaryKey(m_OidPk);

			OIDMaster.remove();

			result = true;
			
		} catch (NamingException e) {
			outputLog(e, "deleteOIDMaster()");
			throw e;
		} catch (EJBException e) {
			outputLog(e, "deleteOIDMaster()");
			throw e;
		} catch (RemoveException e) {
			outputLog(e, "deleteOIDMaster()");
			try {
				throw e;
			} catch (RemoveException e1) {
				outputLog(e1, "deleteOIDMaster()");
			}
		} catch (FinderException e) {
			outputLog(e, "deleteOIDMaster()");
			throw new MonitorNotFoundException(e.getMessage(), e);
		} 
		return result;
	}
	
	/**
     * アプリケーションログにログを出力
     * 
     * @param e 例外
     */
	private void outputLog(Exception e, String method){
		AplLogger apllog = new AplLogger("TRAP", "trap");
		String[] args = {m_OidPk.getMib(),
				         m_OidPk.getTrapOid(),
				         Integer.toString(m_OidPk.getGenericId()),
				         Integer.toString(m_OidPk.getSpecificId())};
        apllog.put("SYS", "001", args);
        m_log.debug(method + ":" + e.getMessage());
	}
}

==> hinemos_src-4.0.0.tar.gz: HinemosManager/src_snmptrap/com/clustercontrol/snmptrap/factory/DeleteOidMaster.java <==
/*

Copyright (C) 2008 NTT DATA Corporation

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.

 */

package com.clustercontrol.snmptrap.factory;

import javax.ejb.CreateException;
import javax.ejb.EJBException;
import javax.ejb.FinderException;
import javax.ejb.RemoveException;
import javax.naming.NamingException;
import javax.transaction.HeuristicMixedException;
import javax.transaction.HeuristicRollbackException;
import javax.transaction.InvalidTransactionException;
import javax.transaction.NotSupportedException;
import javax.transaction.RollbackException;
import javax.transaction.SystemException;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.fault.MonitorNotFound;
import com.clustercontrol.snmptrap.bean.SnmpTrapMasterInfo;
import com.clustercontrol.snmptrap.ejb.entity.SnmpTrapMasterLocal;
import com.clustercontrol.snmptrap.ejb.entity.SnmpTrapMasterPK;
import com.clustercontrol.snmptrap.ejb.entity.SnmpTrapMasterUtil;
import com.clustercontrol.util.apllog.AplLogger;

/**
 * OIDマスター情報を削除するクラス<BR>
 *
 * @version 2.4.0
 * @since 2.4.0
 * @author Yosuke
 */
public class DeleteOidMaster {

	protected static Log m_log = LogFactory.getLog( DeleteOidMaster.class );


	protected SnmpTrapMasterPK m_OidPk;

	/**
	 * OID情報を削除します。
	 * 
	 * @param OIDData　削除するOIDマスター
	 * @param user　　　削除実行ユーザ
	 * @return
	 * @throws CreateException
	 * @throws NotSupportedException
	 * @throws RollbackException
	 * @throws HeuristicMixedException
	 * @throws HeuristicRollbackException
	 * @throws SystemException
	 * @throws InvalidTransactionException
	 * @throws NamingException
	 * @throws MonitorNotFound
	 */
	public boolean delete(SnmpTrapMasterInfo oidData) throws CreateException, NotSupportedException, RollbackException, HeuristicMixedException, HeuristicRollbackException, SystemException, InvalidTransactionException, NamingException, MonitorNotFound {

		this.m_OidPk = new SnmpTrapMasterPK(oidData.getMib(),
				oidData.getTrapOid(),
				oidData.getGenericId(),
				oidData.getSpecificId());

		boolean result = false;

		// 監視情報を登録
		result = deleteOIDMaster();

		return result;
	}

	/**
	 * OIDマスターの削除を行う。
	 * @param user　削除実行ユーザ
	 * @return
	 * @throws NamingException
	 * @throws MonitorNotFound
	 */
	public boolean deleteOIDMaster() throws NamingException, MonitorNotFound {
		boolean result = false;

		try
		{

			// 監視情報を検索

			SnmpTrapMasterLocal OIDMaster =  SnmpTrapMasterUtil.getLocalHome()
			.findByPrimaryKey(m_OidPk);

			OIDMaster.remove();

			result = true;

		} catch (NamingException e) {
			outputLog(e, "deleteOIDMaster()");
			throw e;
		} catch (EJBException e) {
			outputLog(e, "deleteOIDMaster()");
			throw e;
		} catch (RemoveException e) {
			outputLog(e, "deleteOIDMaster()");
			try {
				throw e;
			} catch (RemoveException e1) {
				outputLog(e1, "deleteOIDMaster()");
			}
		} catch (FinderException e) {
			outputLog(e, "deleteOIDMaster()");
			throw new MonitorNotFound(e.getMessage(), e);
		}
		return result;
	}

	/**
	 * アプリケーションログにログを出力
	 * 
	 * @param e 例外
	 */
	private void outputLog(Exception e, String method){
		AplLogger apllog = new AplLogger("TRAP", "trap");
		String[] args = {m_OidPk.getMib(),
				m_OidPk.getTrapOid(),
				Integer.toString(m_OidPk.getGenericId()),
				Integer.toString(m_OidPk.getSpecificId())};
		apllog.put("SYS", "001", args);
		m_log.debug(method + ":" + e.getMessage());
	}
}
